@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp qw(confess);
 
-our $VERSION = '2.12'; # VERSION
+our $VERSION = '2.13'; # VERSION
 
 # ABSTRACT: defines the files that are source of kernel information
 
@@ -17,17 +17,32 @@ sub new {
         $self = {
             sys_osrelease => $opts_ref->{sys_osrelease}
               || '/proc/sys/kernel/osrelease',
-            version           => $opts_ref->{version} || '/proc/version',
-            version_signature => $opts_ref->{version_signature}
-              || '/proc/version_signature',
+            version => $opts_ref->{version} || '/proc/version',
         };
+
+        if ( exists $opts_ref->{version_signature} ) {
+            $self->{version_signature} = $opts_ref->{version_signature};
+        }
+        elsif ( -r '/proc/version_signature' ) {
+            $self->{version_signature} = '/proc/version_signature';
+        }
+        else {
+            $self->{version_signature} = undef;
+        }
+
     }
     else {
         $self = {
-            sys_osrelease     => '/proc/sys/kernel/osrelease',
-            version           => '/proc/version',
-            version_signature => '/proc/version_signature',
+            sys_osrelease => '/proc/sys/kernel/osrelease',
+            version       => '/proc/version',
         };
+
+        if ( -r '/proc/version_signature' ) {
+            $self->{version_signature} = '/proc/version_signature';
+        }
+        else {
+            $self->{version_signature} = undef;
+        }
     }
 
     bless $self, $class;
@@ -90,7 +105,7 @@ Linux::Info::KernelSource - defines the files that are source of kernel informat
 
 =head1 VERSION
 
-version 2.12
+version 2.13
 
 =head1 METHODS
 
